# Configuring SSO with Okta
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta#prerequisites)
  * [Step 1: Create an Application for SSO](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta#step-1:-create-an-application-for-sso)
  * [Step 2: Configure SAML Settings](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta#step-2:-configure-saml-settings)
  * [Step 3: Configure Attribute Mapping](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta#step-3:-configure-attribute-mapping)
  * [Step 4: Assign Users to the Application](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta#step-4:-assign-users-to-the-application)


Instructions for configuring single sign-on (SSO) with Okta as an identity provider.
